---
title: <span class="badge builder"></span> SingleStatBaseOptions
---
# <span class="badge builder"></span> SingleStatBaseOptions

## Constructor

```python
SingleStatBaseOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.SingleStatBaseOptions
```

### <span class="badge object-method"></span> orientation

```python
def orientation(orientation: common.VizOrientation) -> typing.Self
```

### <span class="badge object-method"></span> reduce_options

```python
def reduce_options(reduce_options: cogbuilder.Builder[common.ReduceDataOptions]) -> typing.Self
```

### <span class="badge object-method"></span> text

```python
def text(text: cogbuilder.Builder[common.VizTextDisplayOptions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [SingleStatBaseOptions](./object-SingleStatBaseOptions.md)
